
function SearchAssistant(k,data) {
	this.keywords = k || '';
	this.data = data || {};
	this.type = this.data.type ? this.data.type : "status";
	this.tpl = this.type === 'status' ? 'home' : 'userItem';
	this.title = this.type === 'status' ? "searchStatus" : "searchUser";
	this._orientation = "up";
	this.searchOpen = false;
};

SearchAssistant.prototype.setup = function() {
	
	this.stageController = this.controller.stageController;
	Weibo.Control.setTheme(this.controller);
	
	this.controller.get('search-bar-select').innerHTML = '<img src="images/search_'+this.type+'.png" />';
	
	this.controller.setupWidget(Mojo.Menu.appMenu, Weibo.MenuAttr, Weibo.MenuModel);
	
	this.controller.setupWidget(Mojo.Menu.commandMenu, 
			this.subMenuAttr = {
            	spacerHeight: 0,
            	menuClass: 'no-fade'
            },
			this.subMenuModel = {
            	visible: true,
            	items: [{ icon: 'new', command: 'do-follow'},{},{icon:'refresh', command: 'do-ref'}]
        	}
        );
	
	this.controller.setupWidget(
            "search_field",
            this.textType = {
                hintText: "Search term(s)...",
				focus: true,
				enterSubmits: true,
				multiline: false,
				//modelProperty: 'original',
				//modifierState: Mojo.Widget.sentenceCase,
				focusMode: Mojo.Widget.focusSelectMode,
				textCase: Mojo.Widget.steModeLowerCase,
				changeOnKeyPress:true,
                requiresEnterKey:true
            },
             this.textModel = {value : ''});
             
    this.controller.setupWidget("feedListWgt", 
        this.statusAttr = {
            itemTemplate: "tpl/"+this.tpl,
            listTemplate: "tpl/listTemplate",
            renderLimit: 25
        },    
        this.statusModel = {
            items: ''
        }
    );
    
    this.controller.setupWidget('spinnerBox',
    	this.spinnerSAttrs = {
			spinnerSize: Mojo.Widget.spinnerSmall,
			modelProperty: 'spinning'
		},
	
		this.spinnerModel = {
			spinning: false
		}
	);
    
    if(this.keywords){
    	this.textModel.value = this.keywords;
    	this.controller.modelChanged(this.textModel);
    	this.searchWords(this.keywords);
    }
	
    //this.load();
    
    this.handleKeyDown = this.handleKeyDown.bind(this);
	Mojo.Event.listen(this.controller.document, "keyup", this.handleKeyDown, true);
	
    this.controller.get('app-search-bar-text').innerHTML = this.keywords;
    this.controller.get('app-search-bar-inactive').show();
    this.controller.listen('search_btn_inactive', Mojo.Event.tap,this.startSearch.bind(this));
    this.controller.listen('app-search-bar-scrim', Mojo.Event.tap,this.closeSearch.bind(this));

	this.controller.listen('search-bar-select', Mojo.Event.tap,this.selectType.bind(this));
    
    this.controller.listen('search_btn', Mojo.Event.tap,this.submitSearch.bind(this));
    this.controller.listen('loadMoreBtn', Mojo.Event.tap,this.loadMore.bind(this));
    this.controller.listen('topBox', Mojo.Event.tap,this.scrollToTop.bind(this));
    this.controller.listen('bottomBox', Mojo.Event.tap,this.scrollToBottom.bind(this));
    
    this.controller.listen("feedListWgt", Mojo.Event.listTap,this.pageClick.bindAsEventListener(this));
    //this.controller.listen('pageNext', Mojo.Event.tap,this.nextPage.bind(this));
    //this.controller.listen('app_icon', Mojo.Event.tap,this.indexMenu.bind(this));
    this.controller.listen(this.controller.sceneElement, Mojo.Event.keydown, this.handleKeyDownEvent.bind(this));

	this.controller.listen('loadingTip', Mojo.Event.tap,this.cancelLoad.bind(this));
	this.controller.listen('spinnerBox', Mojo.Event.tap,this.cancelLoad.bind(this));
    
    this.controller.listen("box", Mojo.Event.flick, this.handleFlick.bind(this));
    this.controller.listen("box", Mojo.Event.dragStart, this.handleDragstart.bind(this));
    
};

SearchAssistant.prototype.handleKeyDown = function(e){
    
    if (this.searchOpen == true && Mojo.Char.isEnterKey(e.keyCode)){
	 	this.submitSearch();
	}
	
};

SearchAssistant.prototype.cancelLoad = function() {
	Weibo.Api.cancelReq();
	this.loadTip(false);
	if(Weibo.list[this.title].length < 1){
		this.showLoadMoreBox(false);
	}
	//this.showLoadNewBox(false);
};

SearchAssistant.prototype.pageClick = function(event){
	var eventSrc = event.originalEvent.target || event.target;
	var target = eventSrc.id;
	var name = eventSrc.title;
	
	if(this.data.operate && this.data.operate === 'mention'){
		var str = "@"+this.statusModel.items[event.index].screen_name+" ";
		var params = {action: "insert", text: str,pos:this.data.pos};
		this.stageController.popScenesTo("update", params);
		
	}else{
		Weibo.Opt.pageClick(event,this.title,this.statusModel,this.controller)
		//this.controller.modelChanged(this.statusModel.items[event.index], this);
	}
};

SearchAssistant.prototype.selectType = function(event){
	var findPlace = event.target || event.originalEvent.target;
	this.controller.popupSubmenu({
    		onChoose:  this.gotSearchType,
    		toggleCmd: this.type,
        	placeNear: findPlace,
        	items: [
        		{label:"微博",command:"status"},
        		{label:"用户",command:"user"}
        	]
    	});
};

SearchAssistant.prototype.gotSearchType = function(command){
	if(command){
		
		this.controller.get('search-bar-select').innerHTML = '<img src="images/search_'+command+'.png" />';
		
		this.tpl = command === 'status' ? 'home' : 'userItem';
		this.statusAttr.itemTemplate = "tpl/"+this.tpl;
    	this.controller.modelChanged(this.statusAttr);
		
		var _cm = command === 'status' ? false : true;
		this.subMenuModel.items[0].disabled = _cm;
		this.controller.modelChanged(this.subMenuModel);
		
		if(this.type != command){
			this.type = command;
			this.searchWords(this.keywords);
		}
		this.type = command;
	}
};

SearchAssistant.prototype.startSearch = function(){
	this.searchOpen = true;
	this.controller.get('search_field').mojo.focus();
	this.controller.get('app-search-bar-inactive').hide();
	this.controller.get('app-search-bar-active').show();
	this.controller.get('app-search-bar-scrim').show();
	
};

SearchAssistant.prototype.closeSearch = function(){
	this.searchOpen = false;
	this.controller.get('app-search-bar-inactive').show();
	this.controller.get('app-search-bar-active').hide();
	this.controller.get('app-search-bar-scrim').hide();
};

SearchAssistant.prototype.submitSearch = function() {
    
    var keyword = this.textModel.value; 
		 
    this.textModel.value = keyword;
    this.controller.modelChanged(this.textModel);

	Mojo.Log.info("^^^^^^#search_key"+keyword);
	
	if(keyword){
		this.searchWords(keyword);
		
	}else{
		//this.okButton.mojo.deactivate();
		//this.okButtonActive = false;
		//this.okButtonModel.disabled = false;
		//this.sceneAssistant.modelChanged(this.okButtonModel);
	}

};

SearchAssistant.prototype.showLoadMoreBox = function(flag){
	if(flag == true){
		this.controller.get('loadMoreBox').show();
	}else{
		this.controller.get('loadMoreBox').hide();
	}
};

SearchAssistant.prototype.loadTip = function(flag){

	if(flag == true){
		this.controller.get('loadingTip').addClassName('loading');
		this.controller.get('loadMoreBox').addClassName('loadMoreBoxSelect');
		this.controller.get('loadMoreBox').show();
		this.controller.get('loadMoreBtn').hide();
		this.controller.get('loadMoreStart').show();
	}else{
		this.controller.get('loadingTip').removeClassName('loading');
		this.controller.get('loadMoreBox').removeClassName('loadMoreBoxSelect');
		this.controller.get('loadMoreBox').show();
		this.controller.get('loadMoreBtn').show();
		this.controller.get('loadMoreStart').hide();
	}
	this.spinnerModel.spinning = flag;
	this.controller.modelChanged(this.spinnerModel);

};

SearchAssistant.prototype.showData = function(data,sIndex) {
	this.loadTip(false);
	this.statusModel.items = data;
	this.controller.modelChanged(this.statusModel);
	if(sIndex > -1){
		this.controller.get('feedListWgt').mojo.revealItem(sIndex,true);
	}
};

SearchAssistant.prototype.showFailure = function() {
	this.loadTip(false);
};

SearchAssistant.prototype.searchWords = function(k) {
	
	if(k){
		
		this.keywords = k;
		
		this.closeSearch();
		this.controller.get('app-search-bar-text').innerHTML = this.keywords;
		
		this.page = 1;
		if(this.type === "status"){
			this.title = 'searchStatus';
			Weibo.list['searchStatus'] = [];
			this.isFollow(k);
			this.url = "http://api.t.sina.com.cn/statuses/search.json";
		}else{
			Mojo.Log.info("^^^^^^#search_user"+k);
			this.title = 'searchUser';
			Weibo.list['searchUser'] = [];
			this.url = "http://api.t.sina.com.cn/users/search.json";
		}
		
		var parameters = [['q', k],['count', Weibo.Prefs.count]];
		var _url = Weibo.signRequest(this.url, parameters, "GET");

		Weibo.Api.cancelReq();
		this.loadTip(true);
		this.showLoadMoreBox(false);
		Weibo.Api.loadItem(_url,this.title,this.statusModel,this.controller,'new');

	}

};

SearchAssistant.prototype.isFollow = function(k){
	var thisA = this;
	var url = "http://api.t.sina.com.cn/trends/is_follow.json?topic="+k;
	var parameters = [['topic', k]];
	var _url = Weibo.signRequest(url, parameters, "GET");
	//var _url = Weibo.Oauth.oauthUrl(url,"GET");
	//var oHeader = Weibo.Oauth.oauthHeader(url,"GET");

	var req = new Ajax.Request(_url, {
              method: "get",
              requestHeaders:['Accept-Encoding','gzip,deflate'],
			  //requestHeaders:['Authorization',oHeader,'Accept-Encoding','gzip,deflate'],
              onSuccess: function(resp){

				if (resp.responseJSON) {

					var _follow = resp.responseJSON.is_follow || '';
					
					if( _follow=== "true"){
						thisA.topicid = resp.responseJSON.topicid;
						thisA.subMenuModel.items[0].icon = "stop";
    				}else{
    					thisA.subMenuModel.items[0].icon = "new";
    				}
    			}else{
    				thisA.subMenuModel.items[0].icon = "new";
    			}
    			
    			thisA.controller.modelChanged(thisA.subMenuModel);
              }.bind(this),
              onFailure:function(resp){

              }.bind(this)
       });
};

SearchAssistant.prototype.followTopic = function(type){
	var thisA = this;
	if(type === 'new'){
		var url = "http://api.t.sina.com.cn/trends/follow.json";
		var parameters = [['trend_name', this.keywords]];
		var _method = 'POST';
	}else{
		var url = "http://api.t.sina.com.cn/trends/destroy.json";
		var parameters = [['trend_id', this.topicid]];
		var _method = 'DELETE';
	}

	var postBody = Weibo.signRequest(url, parameters, "POST");

	var req = new Ajax.Request(url, {
				method : 'post', 
				evalJSON : 'force',
				postBody: postBody,
				contentType: 'application/x-www-form-urlencoded',
				onSuccess: function(resp){

					Mojo.Log.info("^^^^^^#2000");
					if(type === 'new'){
						thisA.subMenuModel.items[0].icon = "stop";
						thisA.topicid = resp.responseJSON.topicid;
						Mojo.Controller.getAppController().showBanner({"messageText": '关注"'+thisA.keywords+'"成功'}, {}, Weibo.MainStageName);
					}else{
						thisA.subMenuModel.items[0].icon = "new";
						Mojo.Controller.getAppController().showBanner({"messageText": '取消关注"'+thisA.keywords+'"成功'}, {}, Weibo.MainStageName);
					}
    				
    				thisA.controller.modelChanged(thisA.subMenuModel);
				}

	});
};

SearchAssistant.prototype.loadMore = function(){
	this.loadTip(true);
	this.page = this.page + 1;
	
	//var parameters = this.parameters;
	//parameters.push(['page', this.page]);
	parameters = [['q', this.keywords],['count', Weibo.Prefs.count],['page', this.page]];
	var _url = Weibo.signRequest(this.url, parameters, "GET");
		
	//var url = this.url+"&page="+this.page+"&count="+Weibo.Prefs.count;
    Weibo.Api.loadItem(_url,this.title,this.statusModel,this.controller,'old');
};


SearchAssistant.prototype.operateHandler = function(command) {    
 	if(command) {
    	//this.NavMenuModel.items[1].items[2].iconPath = "images/"+command+".png";
    	//this.controller.modelChanged(this.NavMenuModel);
    	this.stageController.swapScene({transition: Mojo.Transition.crossFade,name: 'listDefault'},command);
    }
};

SearchAssistant.prototype.backMain = function(command) {    
	var app_controller = Mojo.Controller.getAppController();
	var stage_controller = app_controller.getStageController(Weibo.MainStageName);
	var top_scene = stage_controller.getScenes();
	//Mojo.Controller.getAppController().showBanner({"messageText": top_scene[0].sceneName}, {}, Weibo.MainStageName);
	
	if(top_scene[0].sceneName != "listDefault"){
		this.stageController.swapScene({transition: Mojo.Transition.crossFade,name: 'listDefault'});
	}else{
		this.stageController.popScene();
	}
	
};

SearchAssistant.prototype.handleCommand = function(event) {        
    if(event.type == Mojo.Event.command) {
		switch(event.command) {
			case "do-follow":
				this.followTopic(this.subMenuModel.items[0].icon);
				break;
			case "do-ref":
				this.submitSearch();
				break;
			case "do-back":
            	this.backMain();
            	//this.stageController.popScene();
            	break;
		}
	}else if (event.type == Mojo.Event.forward) {
		var postData = [{"title":"update","titleName":"发布微博","oldText":"#"+this.keywords+"#"}];
		this.stageController.pushScene('update',postData);
	}
};

SearchAssistant.prototype.scrollToTop = function() {
	this.scroller = this.controller.getSceneScroller();
    this.scroller.mojo.scrollTo(0, 0);
    this.scroller.mojo.scrollTo(0, 0);
};

SearchAssistant.prototype.scrollToBottom = function() {
	this.scroller = this.controller.getSceneScroller();
	this.scroller.mojo.scrollTo(0, -1 * this.controller.get('feedListWgt').getHeight());
	this.scroller.mojo.scrollTo(0, -1 * this.controller.get('feedListWgt').getHeight());
};

SearchAssistant.prototype.scrollNext = function() {
	this.scroller = this.controller.getSceneScroller();
	this.pageY = this.scroller.mojo.getScrollPosition().top;
	this.scroller.mojo.scrollTo(undefined,  (this.pageY-180), true);
};

SearchAssistant.prototype.scrollPre = function() {
	this.scroller = this.controller.getSceneScroller();
	this.pageY = this.scroller.mojo.getScrollPosition().top;
	this.scroller.mojo.scrollTo(undefined,  (this.pageY+180), true);
};

SearchAssistant.prototype.handleKeyDownEvent = function(event) {

 if(this.searchOpen == false){
    if(event.originalEvent.keyCode == 84){ //t
        this.scrollToTop();
        
    }else if(event.originalEvent.keyCode == 66){//b
        this.scrollToBottom();
    	
    }else if(event.originalEvent.keyCode == 32){ //space
    	this.scrollNext();
    	
    }else if(event.originalEvent.keyCode == 190){ //.
    	this.scrollPre();
       
    }else if(event.originalEvent.keyCode == 70){ //f
        if(this._orientation === "up"){
			if(Weibo.Prefs.fullScreen == false){
				this.setFullScreen(true);
				Weibo.Prefs.fullScreen = true;
			}else{
				this.setFullScreen(false);
				Weibo.Prefs.fullScreen = false;
			}
        }
        
    }else if(event.originalEvent.keyCode == 81){ //q
		this.stageController.popScene();
		
    }else if(event.originalEvent.keyCode == 188){ //,
    	var _pageY = this.scroller.mojo.getScrollPosition().top;
    	var _pageH = this.controller.get('feedListWgt').getHeight();
    	if(_pageY+_pageH<480){
    		this.loadMore();
    	}
    }
  }
    
    //this.controller.get('title').innerHTML = event.originalEvent.keyCode;
  
   
};

SearchAssistant.prototype.handleDragstart = function(evt){
	//this.controller.get('title').innerHTML = "a"+evt.down.y;
	this.downY = evt.down.y;
};

SearchAssistant.prototype.handleFlick = function(evt){
	var LengthX = Math.sqrt(evt.velocity.x*evt.velocity.x);
	var LengthY = Math.sqrt(evt.velocity.y*evt.velocity.y);
	var _twHeight = this.controller.window.innerHeight;

	if (LengthX<1300 || LengthY > 600){
		return;
    }else{
        
		if(this._orientation === "up"){
			if(Weibo.Prefs.fullScreen == false){
				this.setFullScreen(true);
				Weibo.Prefs.fullScreen = true;

			}else{
			   
				if(this.downY > (_twHeight / 2)){
					//this.selectMenu(evt);
				}else{
					this.setFullScreen(false);
					Weibo.Prefs.fullScreen = false;

				}
			}
		}

    }
    
};

SearchAssistant.prototype.setFullScreen = function(type) {
	if(type == true){
		this.controller.enableFullScreenMode(true);
		this.subMenuModel.visible = false;
		this.controller.modelChanged(this.subMenuModel);
		//this.stageController.loadStylesheet("stylesheets/top.css");
		this.controller.get('topBox').style.top = "-24px";
        this.controller.get('bottomBox').style.bottom = "-24px";
		this.controller.get('searchBar').hide();
		this.controller.get('spaceBox').hide();

    }else{
		this.controller.enableFullScreenMode(false);
		this.subMenuModel.visible = true;
		this.controller.modelChanged(this.subMenuModel);
		//this.stageController.unloadStylesheet("stylesheets/top.css");
		this.controller.get('topBox').style.top = "20px";
        this.controller.get('bottomBox').style.bottom = "-15px";
		this.controller.get('searchBar').show();
		this.controller.get('spaceBox').show();

    }
};

SearchAssistant.prototype.orientationChanged = function(orientation){
	this._orientation = orientation;
	if(this._orientation === "left" || this._orientation === "right" || this._orientation === "down"){
		if(Weibo.Prefs.orient === true){
			this.setFullScreen(true);
		}
	}else{
		this.setFullScreen(Weibo.Prefs.fullScreen);
	}
};

SearchAssistant.prototype.activate = function(event) {
	this.setFullScreen(Weibo.Prefs.fullScreen);
	//this.stageController.setWindowOrientation('up');
	if(Weibo.Prefs.orient === true){
		this.controller.stageController.setWindowOrientation('free');
	}else{
		this.controller.stageController.setWindowOrientation('up');
	}
    
    if(!Weibo.Prefs.uid){
		this.controller.stageController.swapScene({transition: Mojo.Transition.crossFade,name: "login"});
	}
};

SearchAssistant.prototype.deactivate = function(event) {
	Mojo.Event.stopListening(this.controller.document, "keyup", this.handleKeyDown, true);
};

SearchAssistant.prototype.cleanup = function(event) {

	this.controller.stopListening('search_btn_inactive', Mojo.Event.tap,this.startSearch.bind(this));
    this.controller.stopListening('app-search-bar-scrim', Mojo.Event.tap,this.closeSearch.bind(this));

	this.controller.stopListening('search-bar-select', Mojo.Event.tap,this.selectType.bind(this));
    
    this.controller.stopListening('search_btn', Mojo.Event.tap,this.submitSearch.bind(this));
    this.controller.stopListening('loadMoreBtn', Mojo.Event.tap,this.loadMore.bind(this));
    this.controller.stopListening("feedListWgt", Mojo.Event.listTap,this.pageClick.bindAsEventListener(this));

    this.controller.stopListening(this.controller.sceneElement, Mojo.Event.keydown, this.handleKeyDownEvent.bind(this));
    Mojo.Event.stopListening(this.controller.document, "keyup", this.handleKeyDown, true);

	this.controller.stopListening('loadingTip', Mojo.Event.tap,this.cancelLoad.bind(this));
	this.controller.stopListening('spinnerBox', Mojo.Event.tap,this.cancelLoad.bind(this));
    
    this.controller.stopListening("box", Mojo.Event.flick, this.handleFlick.bind(this));
    this.controller.stopListening("box", Mojo.Event.dragStart, this.handleDragstart.bind(this));
}